
class Structures:
    ADOBE_CEILING = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeCeiling.PrimalItemStructure_AdobeCeiling'"
    ADOBE_DINOSAUR_GATE = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeGateDoor.PrimalItemStructure_AdobeGateDoor'"
    ADOBE_DINOSAUR_GATEWAY = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeFrameGate.PrimalItemStructure_AdobeFrameGate'"
    ADOBE_DOOR = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeDoor.PrimalItemStructure_AdobeDoor'"
    ADOBE_DOORFRAME = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeWallWithDoor.PrimalItemStructure_AdobeWallWithDoor'"
    ADOBE_DOUBLE_DOORFRAME = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Doorframes_Double/Adobe/PrimalItemStructure_DoubleDoorframe_Adobe.PrimalItemStructure_DoubleDoorframe_Adobe'"
    ADOBE_DOUBLE_DOOR = "Blueprint'/Game/PrimalEarth/StructuresPlus/Doors/Doors_Double/Adobe/PrimalItemStructure_DoubleDoor_Adobe.PrimalItemStructure_DoubleDoor_Adobe'"
    ADOBE_FENCE_FOUNDATION = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeFenceFoundation.PrimalItemStructure_AdobeFenceFoundation'"
    ADOBE_FENCE_SUPPORT = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/FenceSupports/Adobe/PrimalItemStructure_FenceSupport_Adobe.PrimalItemStructure_FenceSupport_Adobe'"
    ADOBE_FOUNDATION = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeFloor.PrimalItemStructure_AdobeFloor'"
    ADOBE_HATCHFRAME = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeCeilingWithTrapdoor.PrimalItemStructure_AdobeCeilingWithTrapdoor'"
    ADOBE_LADDER = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeLader.PrimalItemStructure_AdobeLader'"
    ADOBE_PILLAR = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobePillar.PrimalItemStructure_AdobePillar'"
    ADOBE_RAILING = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeRailing.PrimalItemStructure_AdobeRailing'"
    ADOBE_RAMP = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeRamp.PrimalItemStructure_AdobeRamp'"
    ADOBE_STAIRCASE = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeStaircase.PrimalItemStructure_AdobeStaircase'"
    ADOBE_STAIRS = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Ramps/Adobe/PrimalItemStructure_Ramp_Adobe.PrimalItemStructure_Ramp_Adobe'"
    ADOBE_TRAPDOOR = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeTrapdoor.PrimalItemStructure_AdobeTrapdoor'"
    ADOBE_TRIANGLE_CEILING = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Ceilings/Triangle/Adobe/PrimalItemStructure_TriCeiling_Adobe.PrimalItemStructure_TriCeiling_Adobe'"
    ADOBE_TRIANGLE_FOUNDATION = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Foundations/Triangle/Adobe/PrimalItemStructure_TriFoundation_Adobe.PrimalItemStructure_TriFoundation_Adobe'"
    ADOBE_TRIANGLE_ROOF = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Roofs_Tri/Adobe/PrimalItemStructure_TriRoof_Adobe.PrimalItemStructure_TriRoof_Adobe'"
    ADOBE_WALL = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeWall.PrimalItemStructure_AdobeWall'"
    ADOBE_WINDOW = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeWindow.PrimalItemStructure_AdobeWindow'"
    ADOBE_WINDOWFRAME = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeWallWithWindow.PrimalItemStructure_AdobeWallWithWindow'"
    AIR_CONDITIONER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_AirConditioner.PrimalItemStructure_AirConditioner'"
    ARTIFACT_PEDESTAL = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_TrophyBase.PrimalItemStructure_TrophyBase'"
    AUTO_TURRET = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_Turret.PrimalItemStructure_Turret'"
    BALLISTA_TURRET = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_TurretBallista.PrimalItemStructure_TurretBallista'"
    BEE_HIVE = "Blueprint'/Game/PrimalEarth/Structures/BeeHive/PrimalItemStructure_BeeHive.PrimalItemStructure_BeeHive'"
    BEER_BARREL = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_BeerBarrel.PrimalItemStructure_BeerBarrel'"
    BEHEMOTH_ADOBE_DINOSAUR_GATE = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeGateDoor_Large.PrimalItemStructure_AdobeGateDoor_Large'"
    BEHEMOTH_ADOBE_DINOSAUR_GATEWAY = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeGateframe_Large.PrimalItemStructure_AdobeGateframe_Large'"
    BEHEMOTH_GATEWAY = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalGateframe_Large.PrimalItemStructure_MetalGateframe_Large'"
    BEHEMOTH_GATE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalGate_Large.PrimalItemStructure_MetalGate_Large'"
    BEHEMOTH_REINFORCED_DINOSAUR_GATE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Stone/PrimalItemStructure_StoneGateLarge.PrimalItemStructure_StoneGateLarge'"
    BEHEMOTH_STONE_DINOSAUR_GATEWAY = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Stone/PrimalItemStructure_StoneGateframe_Large.PrimalItemStructure_StoneGateframe_Large'"
    BEHEMOTH_TEK_GATEWAY = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekGateframe_Large.PrimalItemStructure_TekGateframe_Large'"
    BEHEMOTH_TEK_GATE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekGate_Large.PrimalItemStructure_TekGate_Large'"
    BOOKSHELF = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_Bookshelf.PrimalItemStructure_Bookshelf'"
    BUNK_BED = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_Bed_Modern.PrimalItemStructure_Bed_Modern'"
    CAMPFIRE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_Campfire.PrimalItemStructure_Campfire'"
    CANNON = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_Cannon.PrimalItemStructure_Cannon'"
    CATAPULT_TURRET = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_TurretCatapult.PrimalItemStructure_TurretCatapult'"
    CHEMISTRY_BENCH = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_ChemBench.PrimalItemStructure_ChemBench'"
    CLONING_CHAMBER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/BuildingBases/PrimalItemStructure_TekCloningChamber.PrimalItemStructure_TekCloningChamber'"
    COMPOST_BIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_CompostBin.PrimalItemStructure_CompostBin'"
    COOKING_POT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_CookingPot.PrimalItemStructure_CookingPot'"
    CRYOFRIDGE = "Blueprint'/Game/Extinction/CoreBlueprints/Items/PrimalItemStructure_CryoFridge.PrimalItemStructure_CryoFridge'"
    CRYSTAL_WYVERN_QUEEN_FLAG = "Blueprint'/Game/Mods/CrystalIsles/Assets/Dinos/CIBoss/Trophy/PrimalItemStructure_Flag_CIBoss.PrimalItemStructure_Flag_CIBoss'"
    DELIVERY_CRATE = "Blueprint'/Game/Extinction/Structures/ItemBalloon/PrimalItemStructure_StorageBox_Balloon.PrimalItemStructure_StorageBox_Balloon'"
    DINO_LEASH = "Blueprint'/Game/Extinction/Structures/DinoLeash/PrimalItemStructure_DinoLeash.PrimalItemStructure_DinoLeash'"
    DINOSAUR_GATEWAY = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodGateframe.PrimalItemStructure_WoodGateframe'"
    DINOSAUR_GATE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodGate.PrimalItemStructure_WoodGate'"
    DRAGON_FLAG = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_Flag_Dragon.PrimalItemStructure_Flag_Dragon'"
    ELECTRICAL_CABLE_INTERSECTION = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_PowerCableIntersection.PrimalItemStructure_PowerCableIntersection'"
    ELECTRICAL_GENERATOR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_PowerGenerator.PrimalItemStructure_PowerGenerator'"
    ELECTRICAL_OUTLET = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_PowerOutlet.PrimalItemStructure_PowerOutlet'"
    ELEVATOR_TRACK = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/BuildingBases/PrimalItemStructure_ElevatorTrackBase.PrimalItemStructure_ElevatorTrackBase'"
    FABRICATOR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_Fabricator.PrimalItemStructure_Fabricator'"
    FEEDING_TROUGH = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_FeedingTrough.PrimalItemStructure_FeedingTrough'"
    FISH_BASKET = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_FishBasket.PrimalItemStructure_FishBasket'"
    FLEXIBLE_ELECTRICAL_CABLE = "Blueprint'/Game/PrimalEarth/StructuresPlus/Wires/Flex/PrimalItemStructure_Wire_Flex.PrimalItemStructure_Wire_Flex'"
    GAS_COLLECTOR = "Blueprint'/Game/Aberration/Structures/GasCollector/PrimalItemStructure_GasCollector.PrimalItemStructure_GasCollector'"
    GIANT_ADOBE_HATCHFRAME = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeCeilingWithDoorWay_Giant.PrimalItemStructure_AdobeCeilingWithDoorWay_Giant'"
    GIANT_ADOBE_TRAPDOOR = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeCeilingDoorGiant.PrimalItemStructure_AdobeCeilingDoorGiant'"
    GIANT_METAL_HATCHFRAME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalCeilingWithTrapdoorGiant.PrimalItemStructure_MetalCeilingWithTrapdoorGiant'"
    GIANT_METAL_TRAPDOOR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalTrapdoorGiant.PrimalItemStructure_MetalTrapdoorGiant'"
    GIANT_REINFORCED_TRAPDOOR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Stone/PrimalItemStructure_StoneCeilingDoorGiant.PrimalItemStructure_StoneCeilingDoorGiant'"
    GIANT_STONE_HATCHFRAME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Stone/PrimalItemStructure_StoneCeilingWithTrapdoorGiant.PrimalItemStructure_StoneCeilingWithTrapdoorGiant'"
    GORILLA_FLAG = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_Flag_Gorilla.PrimalItemStructure_Flag_Gorilla'"
    GRAVESTONE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_Furniture_Gravestone.PrimalItemStructure_Furniture_Gravestone'"
    GREENHOUSE_CEILING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Greenhouse/PrimalItemStructure_GreenhouseCeiling.PrimalItemStructure_GreenhouseCeiling'"
    GREENHOUSE_DOORFRAME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Greenhouse/PrimalItemStructure_GreenhouseWallWithDoor.PrimalItemStructure_GreenhouseWallWithDoor'"
    GREENHOUSE_DOOR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Greenhouse/PrimalItemStructure_GreenhouseDoor.PrimalItemStructure_GreenhouseDoor'"
    GREENHOUSE_DOUBLE_DOORFRAME = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Doorframes_Double/Greenhouse/PrimalItemStructure_DoubleDoorframe_Greenhouse.PrimalItemStructure_DoubleDoorframe_Greenhouse'"
    GREENHOUSE_DOUBLE_DOOR = "Blueprint'/Game/PrimalEarth/StructuresPlus/Doors/Doors_Double/Greenhouse/PrimalItemStructure_DoubleDoor_Greenhouse.PrimalItemStructure_DoubleDoor_Greenhouse'"
    GREENHOUSE_TRIANGLE_CEILING = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Ceilings/Triangle/Greenhouse/PrimalItemStructure_TriCeiling_Greenhouse.PrimalItemStructure_TriCeiling_Greenhouse'"
    GREENHOUSE_TRIANGLE_ROOF = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Roofs_Tri/Greenhouse/PrimalItemStructure_TriRoof_Greenhouse.PrimalItemStructure_TriRoof_Greenhouse'"
    GREENHOUSE_WALL = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Greenhouse/PrimalItemStructure_GreenhouseWall.PrimalItemStructure_GreenhouseWall'"
    GREENHOUSE_WINDOW = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Greenhouse/PrimalItemStructure_GreenhouseWindow.PrimalItemStructure_GreenhouseWindow'"
    HEAVY_AUTO_TURRET = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_HeavyTurret.PrimalItemStructure_HeavyTurret'"
    HIDE_SLEEPING_BAG = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_SleepingBag_Hide.PrimalItemStructure_SleepingBag_Hide'"
    HOMING_UNDERWATER_MINE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_SeaMine.PrimalItemStructure_SeaMine'"
    INCLINED_ELECTRICAL_CABLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_PowerCableIncline.PrimalItemStructure_PowerCableIncline'"
    INDUSTRIAL_COOKER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_IndustrialCookingPot.PrimalItemStructure_IndustrialCookingPot'"
    INDUSTRIAL_FORGE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_IndustrialForge.PrimalItemStructure_IndustrialForge'"
    INDUSTRIAL_GRILL = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_Grill.PrimalItemStructure_Grill'"
    INDUSTRIAL_GRINDER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_Grinder.PrimalItemStructure_Grinder'"
    KING_TITAN_FLAG = "Blueprint'/Game/Extinction/CoreBlueprints/Trophies/PrimalItemStructure_Flag_KingKaiju.PrimalItemStructure_Flag_KingKaiju'"
    KING_TITAN_FLAG_MECHA = "Blueprint'/Game/Extinction/CoreBlueprints/Trophies/PrimalItemStructure_Flag_KingKaijuMecha.PrimalItemStructure_Flag_KingKaijuMecha'"
    LAMPPOST = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_Lamppost.PrimalItemStructure_Lamppost'"
    LARGE_ADOBE_WALL = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Walls_L/Adobe/PrimalItemStructure_LargeWall_Adobe.PrimalItemStructure_LargeWall_Adobe'"
    LARGE_CROP_PLOT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_CropPlot_Large.PrimalItemStructure_CropPlot_Large'"
    LARGE_ELEVATOR_PLATFORM = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/BuildingBases/PrimalItemStructure_ElevatorPlatformLarge.PrimalItemStructure_ElevatorPlatformLarge'"
    LARGE_METAL_WALL = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Walls_L/Metal/PrimalItemStructure_LargeWall_Metal.PrimalItemStructure_LargeWall_Metal'"
    LARGE_STONE_WALL = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Walls_L/Stone/PrimalItemStructure_LargeWall_Stone.PrimalItemStructure_LargeWall_Stone'"
    LARGE_STORAGE_BOX = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_StorageBox_Large.PrimalItemStructure_StorageBox_Large'"
    LARGE_TAXIDERMY_BASE = "Blueprint'/Game/Extinction/CoreBlueprints/Items/PrimalItemStructure_TaxidermyBase_Large.PrimalItemStructure_TaxidermyBase_Large'"
    LARGE_TEK_WALL = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Walls_L/Tek/PrimalItemStructure_LargeWall_Tek.PrimalItemStructure_LargeWall_Tek'"
    LARGE_WOOD_ELEVATOR_PLATFORM = "Blueprint'/Game/Aberration/Structures/PrimitiveElevator/PrimalItemStructure_WoodElevatorPlatform_Large.PrimalItemStructure_WoodElevatorPlatform_Large'"
    LARGE_WOODEN_WALL = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Walls_L/Wood/PrimalItemStructure_LargeWall_Wood.PrimalItemStructure_LargeWall_Wood'"
    MANTICORE_FLAG = "Blueprint'/Game/ScorchedEarth/Structures/ManticoreFlag/PrimalItemStructure_Flag_Manticore.PrimalItemStructure_Flag_Manticore'"
    MEDIUM_CROP_PLOT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_CropPlot_Medium.PrimalItemStructure_CropPlot_Medium'"
    MEDIUM_ELEVATOR_PLATFORM = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/BuildingBases/PrimalItemStructure_ElevatorPlatfromMedium.PrimalItemStructure_ElevatorPlatfromMedium'"
    MEDIUM_TAXIDERMY_BASE = "Blueprint'/Game/Extinction/CoreBlueprints/Items/PrimalItemStructure_TaxidermyBase_Medium.PrimalItemStructure_TaxidermyBase_Medium'"
    MEDIUM_WOOD_ELEVATOR_PLATFORM = "Blueprint'/Game/Aberration/Structures/PrimitiveElevator/PrimalItemStructure_WoodElevatorPlatform_Medium.PrimalItemStructure_WoodElevatorPlatform_Medium'"
    METAL_BILLBOARD = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalSign_Large.PrimalItemStructure_MetalSign_Large'"
    METAL_CATWALK = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalCatwalk.PrimalItemStructure_MetalCatwalk'"
    METAL_CEILING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalCeiling.PrimalItemStructure_MetalCeiling'"
    METAL_CLIFF_PLATFORM = "Blueprint'/Game/Aberration/Structures/CliffPlatforms/Metal_CliffPlatform/PrimalItemStructure_Metal_CliffPlatform.PrimalItemStructure_Metal_CliffPlatform'"
    METAL_DINOSAUR_GATEWAY = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalGateframe.PrimalItemStructure_MetalGateframe'"
    METAL_DINOSAUR_GATE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalGate.PrimalItemStructure_MetalGate'"
    METAL_DOORFRAME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalWallWithDoor.PrimalItemStructure_MetalWallWithDoor'"
    METAL_DOOR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalDoor.PrimalItemStructure_MetalDoor'"
    METAL_DOUBLE_DOORFRAME = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Doorframes_Double/Metal/PrimalItemStructure_DoubleDoorframe_Metal.PrimalItemStructure_DoubleDoorframe_Metal'"
    METAL_DOUBLE_DOOR = "Blueprint'/Game/PrimalEarth/StructuresPlus/Doors/Doors_Double/Metal/PrimalItemStructure_DoubleDoor_Metal.PrimalItemStructure_DoubleDoor_Metal'"
    METAL_FENCE_FOUNDATION = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalFenceFoundation.PrimalItemStructure_MetalFenceFoundation'"
    METAL_FENCE_SUPPORT = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/FenceSupports/Metal/PrimalItemStructure_FenceSupport_Metal.PrimalItemStructure_FenceSupport_Metal'"
    METAL_FOUNDATION = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalFloor.PrimalItemStructure_MetalFloor'"
    METAL_HATCHFRAME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalCeilingWithTrapdoor.PrimalItemStructure_MetalCeilingWithTrapdoor'"
    METAL_IRRIGATION_PIPE_FLEXIBLE = "Blueprint'/Game/PrimalEarth/StructuresPlus/Pipes/Flex/Metal/PrimalItemStructure_PipeFlex_Metal.PrimalItemStructure_PipeFlex_Metal'"
    METAL_IRRIGATION_PIPE_INCLINED = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_MetalPipeIncline.PrimalItemStructure_MetalPipeIncline'"
    METAL_IRRIGATION_PIPE_INTAKE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_MetalPipeIntake.PrimalItemStructure_MetalPipeIntake'"
    METAL_IRRIGATION_PIPE_INTERSECTION = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_MetalPipeIntersection.PrimalItemStructure_MetalPipeIntersection'"
    METAL_IRRIGATION_PIPE_STRAIGHT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_MetalPipeStraight.PrimalItemStructure_MetalPipeStraight'"
    METAL_IRRIGATION_PIPE_TAP = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_MetalPipeTap.PrimalItemStructure_MetalPipeTap'"
    METAL_IRRIGATION_PIPE_VERTICAL = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_MetalPipeVertical.PrimalItemStructure_MetalPipeVertical'"
    METAL_LADDER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalLadder.PrimalItemStructure_MetalLadder'"
    METAL_OCEAN_PLATFORM = "Blueprint'/Game/Genesis/Structures/OceanPlatform/OceanPlatform_Wood/PrimalItemStructure_Metal_OceanPlatform.PrimalItemStructure_Metal_OceanPlatform'"
    METAL_PILLAR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalPillar.PrimalItemStructure_MetalPillar'"
    METAL_RAILING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalRailing.PrimalItemStructure_MetalRailing'"
    METAL_RAMP = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalRamp.PrimalItemStructure_MetalRamp'"
    METAL_SIGN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalSign.PrimalItemStructure_MetalSign'"
    METAL_SPIKE_WALL = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalSpikeWall.PrimalItemStructure_MetalSpikeWall'"
    METAL_STAIRCASE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalStairs.PrimalItemStructure_MetalStairs'"
    METAL_STAIRS = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Ramps/Metal/PrimalItemStructure_Ramp_Metal.PrimalItemStructure_Ramp_Metal'"
    METAL_TRAPDOOR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalTrapdoor.PrimalItemStructure_MetalTrapdoor'"
    METAL_TREE_PLATFORM = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_TreePlatform_Metal.PrimalItemStructure_TreePlatform_Metal'"
    METAL_TRIANGLE_CEILING = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Ceilings/Triangle/Metal/PrimalItemStructure_TriCeiling_Metal.PrimalItemStructure_TriCeiling_Metal'"
    METAL_TRIANGLE_FOUNDATION = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Foundations/Triangle/Metal/PrimalItemStructure_TriFoundation_Metal.PrimalItemStructure_TriFoundation_Metal'"
    METAL_TRIANGLE_ROOF = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Roofs_Tri/Metal/PrimalItemStructure_TriRoof_Metal.PrimalItemStructure_TriRoof_Metal'"
    METAL_WALL_SIGN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalSign_Wall.PrimalItemStructure_MetalSign_Wall'"
    METAL_WALL = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalWall.PrimalItemStructure_MetalWall'"
    METAL_WATER_RESERVOIR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_WaterTankMetal.PrimalItemStructure_WaterTankMetal'"
    METAL_WINDOWFRAME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalWallWithWindow.PrimalItemStructure_MetalWallWithWindow'"
    METAL_WINDOW = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Metal/PrimalItemStructure_MetalWindow.PrimalItemStructure_MetalWindow'"
    MINIGUN_TURRET = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_TurretMinigun.PrimalItemStructure_TurretMinigun'"
    MIRROR = "Blueprint'/Game/ScorchedEarth/Structures/DesertFurnitureSet/Mirror/PrimalItemStructure_Mirror.PrimalItemStructure_Mirror'"
    MOEDER_FLAG = "Blueprint'/Game/Genesis/CoreBlueprints/Structures/PrimalItemStructure_Flag_EelBoss.PrimalItemStructure_Flag_EelBoss'"
    MORTAR_AND_PESTLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_MortarAndPestle.PrimalItemStructure_MortarAndPestle'"
    MOTORBOAT = "Blueprint'/Game/PrimalEarth/Items/Raft/PrimalItemMotorboat.PrimalItemMotorboat'"
    MULTI_PANEL_FLAG = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_Flag.PrimalItemStructure_Flag'"
    OIL_PUMP = "Blueprint'/Game/ScorchedEarth/Structures/OilPump/PrimalItemStructure_oilPump.PrimalItemStructure_oilPump'"
    OMNIDIRECTIONAL_LAMPPOST = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_LamppostOmni.PrimalItemStructure_LamppostOmni'"
    PAINTING_CANVAS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_PaintingCanvas.PrimalItemStructure_PaintingCanvas'"
    PORTABLE_ROPE_LADDER = "Blueprint'/Game/Aberration/Structures/PortableRopeLadder/PrimalItemStructure_PortableLadder.PrimalItemStructure_PortableLadder'"
    PRESERVING_BIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_PreservingBin.PrimalItemStructure_PreservingBin'"
    PRESSURE_PLATE = "Blueprint'/Game/Genesis/Structures/TekAlarm/PrimalItemStructure_PressurePlate.PrimalItemStructure_PressurePlate'"
    REFINING_FORGE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_Forge.PrimalItemStructure_Forge'"
    REFRIGERATOR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_IceBox.PrimalItemStructure_IceBox'"
    REINFORCED_DINOSAUR_GATE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Stone/PrimalItemStructure_StoneGate.PrimalItemStructure_StoneGate'"
    REINFORCED_DOUBLE_DOOR = "Blueprint'/Game/PrimalEarth/StructuresPlus/Doors/Doors_Double/Stone/PrimalItemStructure_DoubleDoor_Stone.PrimalItemStructure_DoubleDoor_Stone'"
    REINFORCED_TRAPDOOR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_StoneTrapdoor.PrimalItemStructure_StoneTrapdoor'"
    REINFORCED_WINDOW = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_StoneWindow.PrimalItemStructure_StoneWindow'"
    REINFORCED_WOODEN_DOOR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Stone/PrimalItemStructure_StoneDoor.PrimalItemStructure_StoneDoor'"
    REMOTE_KEYPAD = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_Keypad.PrimalItemStructure_Keypad'"
    ROCKET_TURRET = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_TurretRocket.PrimalItemStructure_TurretRocket'"
    ROCKWELL_FLAG = "Blueprint'/Game/Aberration/CoreBlueprints/Items/Trophies/PrimalItemStructure_Flag_Rockwell.PrimalItemStructure_Flag_Rockwell'"
    ROPE_LADDER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_RopeLadder.PrimalItemStructure_RopeLadder'"
    SHAG_RUG = "Blueprint'/Game/Aberration/CoreBlueprints/Items/Structures/PrimalItemStructure_Furniture_Rug.PrimalItemStructure_Furniture_Rug'"
    SIMPLE_BED = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_Bed_Simple.PrimalItemStructure_Bed_Simple'"
    SINGLE_PANEL_FLAG = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_Flag_Single.PrimalItemStructure_Flag_Single'"
    SLOPED_ADOBE_ROOF = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeRoof.PrimalItemStructure_AdobeRoof'"
    SLOPED_ADOBE_WALL_LEFT = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeWall_Sloped_Left.PrimalItemStructure_AdobeWall_Sloped_Left'"
    SLOPED_ADOBE_WALL_RIGHT = "Blueprint'/Game/ScorchedEarth/Structures/Adobe/Blueprints/PrimalItemStructure_AdobeWall_Sloped_Right.PrimalItemStructure_AdobeWall_Sloped_Right'"
    SLOPED_GREENHOUSE_ROOF = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Greenhouse/PrimalItemStructure_GreenhouseRoof.PrimalItemStructure_GreenhouseRoof'"
    SLOPED_GREENHOUSE_WALL_LEFT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Greenhouse/PrimalItemStructure_GreenhouseWall_Sloped_Left.PrimalItemStructure_GreenhouseWall_Sloped_Left'"
    SLOPED_GREENHOUSE_WALL_RIGHT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Greenhouse/PrimalItemStructure_GreenhouseWall_Sloped_Right.PrimalItemStructure_GreenhouseWall_Sloped_Right'"
    SLOPED_METAL_ROOF = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Roofs/Metal/PrimalItemStructure_MetalRoof.PrimalItemStructure_MetalRoof'"
    SLOPED_METAL_WALL_LEFT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Roofs/Metal/PrimalItemStructure_MetalWall_Sloped_Left.PrimalItemStructure_MetalWall_Sloped_Left'"
    SLOPED_METAL_WALL_RIGHT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Roofs/Metal/PrimalItemStructure_MetalWall_Sloped_Right.PrimalItemStructure_MetalWall_Sloped_Right'"
    SLOPED_STONE_ROOF = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Roofs/Stone/PrimalItemStructure_StoneRoof.PrimalItemStructure_StoneRoof'"
    SLOPED_STONE_WALL_LEFT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Roofs/Stone/PrimalItemStructure_StoneWall_Sloped_Left.PrimalItemStructure_StoneWall_Sloped_Left'"
    SLOPED_STONE_WALL_RIGHT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Roofs/Stone/PrimalItemStructure_StoneWall_Sloped_Right.PrimalItemStructure_StoneWall_Sloped_Right'"
    SLOPED_TEK_ROOF = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekRoof.PrimalItemStructure_TekRoof'"
    SLOPED_TEK_WALL_LEFT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekWall_Sloped_Left.PrimalItemStructure_TekWall_Sloped_Left'"
    SLOPED_TEK_WALL_RIGHT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekWall_Sloped_Right.PrimalItemStructure_TekWall_Sloped_Right'"
    SLOPED_THATCH_ROOF = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Roofs/Thatch/PrimalItemStructure_ThatchRoof.PrimalItemStructure_ThatchRoof'"
    SLOPED_THATCH_WALL_LEFT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Roofs/Thatch/PrimalItemStructure_ThatchWall_Sloped_Left.PrimalItemStructure_ThatchWall_Sloped_Left'"
    SLOPED_THATCH_WALL_RIGHT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Roofs/Thatch/PrimalItemStructure_ThatchWall_Sloped_Right.PrimalItemStructure_ThatchWall_Sloped_Right'"
    SLOPED_WOOD_WALL_LEFT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Roofs/Wood/PrimalItemStructure_WoodWall_Sloped_Left.PrimalItemStructure_WoodWall_Sloped_Left'"
    SLOPED_WOOD_WALL_RIGHT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Roofs/Wood/PrimalItemStructure_WoodWall_Sloped_Right.PrimalItemStructure_WoodWall_Sloped_Right'"
    SLOPED_WOODEN_ROOF = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Roofs/Wood/PrimalItemStructure_WoodRoof.PrimalItemStructure_WoodRoof'"
    SMALL_CROP_PLOT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_CropPlot_Small.PrimalItemStructure_CropPlot_Small'"
    SMALL_ELEVATOR_PLATFORM = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/BuildingBases/PrimalItemStructure_ElevatorPlatformSmall.PrimalItemStructure_ElevatorPlatformSmall'"
    SMALL_TAXIDERMY_BASE = "Blueprint'/Game/Extinction/CoreBlueprints/Items/PrimalItemStructure_TaxidermyBase_Small.PrimalItemStructure_TaxidermyBase_Small'"
    SMALL_WOOD_ELEVATOR_PLATFORM = "Blueprint'/Game/Aberration/Structures/PrimitiveElevator/PrimalItemStructure_WoodElevatorPlatform_Small.PrimalItemStructure_WoodElevatorPlatform_Small'"
    SMITHY = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_AnvilBench.PrimalItemStructure_AnvilBench'"
    SPIDER_FLAG = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_Flag_Spider.PrimalItemStructure_Flag_Spider'"
    STANDING_TORCH = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_StandingTorch.PrimalItemStructure_StandingTorch'"
    STONE_CEILING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Stone/PrimalItemStructure_StoneCeiling.PrimalItemStructure_StoneCeiling'"
    STONE_CLIFF_PLATFORM = "Blueprint'/Game/Aberration/Structures/CliffPlatforms/Stone_CliffPlatform/PrimalItemStructure_Stone_CliffPlatform.PrimalItemStructure_Stone_CliffPlatform'"
    STONE_DINOSAUR_GATEWAY = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Stone/PrimalItemStructure_StoneGateframe.PrimalItemStructure_StoneGateframe'"
    STONE_DOORFRAME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Stone/PrimalItemStructure_StoneWallWithDoor.PrimalItemStructure_StoneWallWithDoor'"
    STONE_DOUBLE_DOORFRAME = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Doorframes_Double/Stone/PrimalItemStructure_DoubleDoorframe_Stone.PrimalItemStructure_DoubleDoorframe_Stone'"
    STONE_FENCE_FOUNDATION = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Stone/PrimalItemStructure_StoneFenceFoundation.PrimalItemStructure_StoneFenceFoundation'"
    STONE_FENCE_SUPPORT = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/FenceSupports/Stone/PrimalItemStructure_FenceSupport_Stone.PrimalItemStructure_FenceSupport_Stone'"
    STONE_FIREPLACE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_Fireplace.PrimalItemStructure_Fireplace'"
    STONE_FOUNDATION = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Stone/PrimalItemStructure_StoneFloor.PrimalItemStructure_StoneFloor'"
    STONE_HATCHFRAME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Stone/PrimalItemStructure_StoneCeilingWithTrapdoor.PrimalItemStructure_StoneCeilingWithTrapdoor'"
    STONE_IRRIGATION_PIPE_FLEXIBLE = "Blueprint'/Game/PrimalEarth/StructuresPlus/Pipes/Flex/Stone/PrimalItemStructure_PipeFlex_Stone.PrimalItemStructure_PipeFlex_Stone'"
    STONE_IRRIGATION_PIPE_INCLINED = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_StonePipeIncline.PrimalItemStructure_StonePipeIncline'"
    STONE_IRRIGATION_PIPE_INTAKE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_StonePipeIntake.PrimalItemStructure_StonePipeIntake'"
    STONE_IRRIGATION_PIPE_INTERSECTION = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_StonePipeIntersection.PrimalItemStructure_StonePipeIntersection'"
    STONE_IRRIGATION_PIPE_STRAIGHT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_StonePipeStraight.PrimalItemStructure_StonePipeStraight'"
    STONE_IRRIGATION_PIPE_TAP = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_StonePipeTap.PrimalItemStructure_StonePipeTap'"
    STONE_IRRIGATION_PIPE_VERTICAL = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_StonePipeVertical.PrimalItemStructure_StonePipeVertical'"
    STONE_PILLAR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Stone/PrimalItemStructure_StonePillar.PrimalItemStructure_StonePillar'"
    STONE_RAILING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Stone/PrimalItemStructure_StoneRailing.PrimalItemStructure_StoneRailing'"
    STONE_STAIRCASE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Stone/PrimalItemStructure_StoneStairs.PrimalItemStructure_StoneStairs'"
    STONE_STAIRS = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Ramps/Stone/PrimalItemStructure_Ramp_Stone.PrimalItemStructure_Ramp_Stone'"
    STONE_TRIANGLE_CEILING = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Ceilings/Triangle/Stone/PrimalItemStructure_TriCeiling_Stone.PrimalItemStructure_TriCeiling_Stone'"
    STONE_TRIANGLE_FOUNDATION = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Foundations/Triangle/Stone/PrimalItemStructure_TriFoundation_Stone.PrimalItemStructure_TriFoundation_Stone'"
    STONE_TRIANGLE_ROOF = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Roofs_Tri/Stone/PrimalItemStructure_TriRoof_Stone.PrimalItemStructure_TriRoof_Stone'"
    STONE_WALL = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Stone/PrimalItemStructure_StoneWall.PrimalItemStructure_StoneWall'"
    STONE_WINDOWFRAME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Stone/PrimalItemStructure_StoneWallWithWindow.PrimalItemStructure_StoneWallWithWindow'"
    STORAGE_BOX = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_StorageBox_Small.PrimalItemStructure_StorageBox_Small'"
    STRAIGHT_ELECTRICAL_CABLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_PowerCableStraight.PrimalItemStructure_PowerCableStraight'"
    TEK_BRIDGE = "Blueprint'/Game/Extinction/Structures/TekBridge/PrimalItemStructure_TekBridge.PrimalItemStructure_TekBridge'"
    TEK_CATWALK = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekCatwalk.PrimalItemStructure_TekCatwalk'"
    TEK_CEILING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekCeiling.PrimalItemStructure_TekCeiling'"
    TEK_DEDICATED_STORAGE = "Blueprint'/Game/PrimalEarth/StructuresPlus/Misc/DedicatedStorage/PrimalItemStructure_DedicatedStorage.PrimalItemStructure_DedicatedStorage'"
    TEK_DINOSAUR_GATEWAY = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekGateframe.PrimalItemStructure_TekGateframe'"
    TEK_DINOSAUR_GATE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekGate.PrimalItemStructure_TekGate'"
    TEK_DOORFRAME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekWallWithDoor.PrimalItemStructure_TekWallWithDoor'"
    TEK_DOOR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekDoor.PrimalItemStructure_TekDoor'"
    TEK_DOUBLE_DOORFRAME = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Doorframes_Double/Tek/PrimalItemStructure_DoubleDoorframe_Tek.PrimalItemStructure_DoubleDoorframe_Tek'"
    TEK_DOUBLE_DOOR = "Blueprint'/Game/PrimalEarth/StructuresPlus/Doors/Doors_Double/Tek/PrimalItemStructure_DoubleDoor_Tek.PrimalItemStructure_DoubleDoor_Tek'"
    TEK_FENCE_FOUNDATION = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekFenceFoundation.PrimalItemStructure_TekFenceFoundation'"
    TEK_FENCE_SUPPORT = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/FenceSupports/Tek/PrimalItemStructure_FenceSupport_Tek.PrimalItemStructure_FenceSupport_Tek'"
    TEK_FORCEFIELD = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_TekShield.PrimalItemStructure_TekShield'"
    TEK_FOUNDATION = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekFloor.PrimalItemStructure_TekFloor'"
    TEK_GENERATOR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_TekGenerator.PrimalItemStructure_TekGenerator'"
    TEK_HATCHFRAME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekCeilingWithTrapdoor.PrimalItemStructure_TekCeilingWithTrapdoor'"
    TEK_JUMP_PAD = "Blueprint'/Game/Genesis/Structures/TekJumpPad/PrimalItemStructure_TekJumpPad.PrimalItemStructure_TekJumpPad'"
    TEK_LADDER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekLadder.PrimalItemStructure_TekLadder'"
    TEK_LIGHT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_TekLight.PrimalItemStructure_TekLight'"
    TEK_PILLAR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekPillar.PrimalItemStructure_TekPillar'"
    TEK_RAILING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekRailing.PrimalItemStructure_TekRailing'"
    TEK_RAMP = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekRamp.PrimalItemStructure_TekRamp'"
    TEK_REPLICATOR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_TekReplicator.PrimalItemStructure_TekReplicator'"
    TEK_SENSOR = "Blueprint'/Game/Genesis/Structures/TekAlarm/PrimalItemStructure_TekAlarm.PrimalItemStructure_TekAlarm'"
    TEK_SLEEPING_POD = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_Bed_Tek.PrimalItemStructure_Bed_Tek'"
    TEK_STAIRCASE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekStairs.PrimalItemStructure_TekStairs'"
    TEK_STAIRS = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Ramps/Tek/PrimalItemStructure_Ramp_Tek.PrimalItemStructure_Ramp_Tek'"
    TEK_TELEPORTER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_TekTeleporter.PrimalItemStructure_TekTeleporter'"
    TEK_TRANSMITTER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_TekTransmitter.PrimalItemStructure_TekTransmitter'"
    TEK_TRAPDOOR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekTrapdoor.PrimalItemStructure_TekTrapdoor'"
    TEK_TRIANGLE_CEILING = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Ceilings/Triangle/Tek/PrimalItemStructure_TriCeiling_Tek.PrimalItemStructure_TriCeiling_Tek'"
    TEK_TRIANGLE_FOUNDATION = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Foundations/Triangle/Tek/PrimalItemStructure_TriFoundation_Tek.PrimalItemStructure_TriFoundation_Tek'"
    TEK_TRIANGLE_ROOF = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Roofs_Tri/Tek/PrimalItemStructure_TriRoof_Tek.PrimalItemStructure_TriRoof_Tek'"
    TEK_TROUGH = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_TekTrough.PrimalItemStructure_TekTrough'"
    TEK_TURRET = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_TurretTek.PrimalItemStructure_TurretTek'"
    TEK_WALL = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekWall.PrimalItemStructure_TekWall'"
    TEK_WINDOWFRAME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekWallWithWindow.PrimalItemStructure_TekWallWithWindow'"
    TEK_WINDOW = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Tek/PrimalItemStructure_TekWindow.PrimalItemStructure_TekWindow'"
    TENT = "Blueprint'/Game/ScorchedEarth/Structures/Tent/PrimalItemStructure_Tent.PrimalItemStructure_Tent'"
    THATCH_CEILING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Thatch/PrimalItemStructure_ThatchCeiling.PrimalItemStructure_ThatchCeiling'"
    THATCH_DOORFRAME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Thatch/PrimalItemStructure_ThatchWallWithDoor.PrimalItemStructure_ThatchWallWithDoor'"
    THATCH_DOOR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Thatch/PrimalItemStructure_ThatchDoor.PrimalItemStructure_ThatchDoor'"
    THATCH_FOUNDATION = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Thatch/PrimalItemStructure_ThatchFloor.PrimalItemStructure_ThatchFloor'"
    THATCH_WALL = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Thatch/PrimalItemStructure_ThatchWall.PrimalItemStructure_ThatchWall'"
    TOILET = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_Toilet.PrimalItemStructure_Toilet'"
    TRAINING_DUMMY = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Halloween/PrimalItemStructure_TrainingDummy.PrimalItemStructure_TrainingDummy'"
    TREE_SAP_TAP = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_TreeTap.PrimalItemStructure_TreeTap'"
    TROPHY_WALL_MOUNT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_TrophyWall.PrimalItemStructure_TrophyWall'"
    VACUUM_COMPARTMENT_MOONPOOL = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/BuildingBases/PrimalItemStructure_UnderwaterBase_Moonpool.PrimalItemStructure_UnderwaterBase_Moonpool'"
    VACUUM_COMPARTMENT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/BuildingBases/PrimalItemStructure_UnderwaterBase.PrimalItemStructure_UnderwaterBase'"
    VAULT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_StorageBox_Huge.PrimalItemStructure_StorageBox_Huge'"
    VERTICAL_ELECTRICAL_CABLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_PowerCableVertical.PrimalItemStructure_PowerCableVertical'"
    VESSEL = "Blueprint'/Game/ScorchedEarth/Structures/DesertFurnitureSet/Vessel/PrimalItemStructure_Vessel.PrimalItemStructure_Vessel'"
    VR_BOSS_FLAG = "Blueprint'/Game/Genesis/CoreBlueprints/Structures/PrimalItemStructure_Flag_VRBoss.PrimalItemStructure_Flag_VRBoss'"
    WALL_TORCH = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_WallTorch.PrimalItemStructure_WallTorch'"
    WAR_MAP = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WarMap.PrimalItemStructure_WarMap'"
    WARDRUMS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_Wardrums.PrimalItemStructure_Wardrums'"
    WATER_RESERVOIR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Pipes/PrimalItemStructure_WaterTank.PrimalItemStructure_WaterTank'"
    WATER_WELL = "Blueprint'/Game/ScorchedEarth/Structures/WaterWell/PrimalItemStructure_WaterWell.PrimalItemStructure_WaterWell'"
    WIND_TURBINE = "Blueprint'/Game/ScorchedEarth/Structures/WindTurbine/PrimalItemStructure_WindTurbine.PrimalItemStructure_WindTurbine'"
    WOOD_ELEVATOR_TOP_SWITCH = "Blueprint'/Game/Aberration/Structures/PrimitiveElevator/PrimalItemStructure_WoodElevatorTopSwitch.PrimalItemStructure_WoodElevatorTopSwitch'"
    WOOD_ELEVATOR_TRACK = "Blueprint'/Game/Aberration/Structures/PrimitiveElevator/PrimalItemStructure_WoodElevatorTrack.PrimalItemStructure_WoodElevatorTrack'"
    WOOD_OCEAN_PLATFORM = "Blueprint'/Game/Genesis/Structures/OceanPlatform/OceanPlatform_Wood/PrimalItemStructure_Wood_OceanPlatform.PrimalItemStructure_Wood_OceanPlatform'"
    WOODEN_BENCH = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_Furniture_WoodBench.PrimalItemStructure_Furniture_WoodBench'"
    WOODEN_BILLBOARD = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodSign_Large.PrimalItemStructure_WoodSign_Large'"
    WOODEN_CAGE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodCage.PrimalItemStructure_WoodCage'"
    WOODEN_CATWALK = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodCatwalk.PrimalItemStructure_WoodCatwalk'"
    WOODEN_CEILING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodCeiling.PrimalItemStructure_WoodCeiling'"
    WOODEN_CHAIR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_Furniture_WoodChair.PrimalItemStructure_Furniture_WoodChair'"
    WOODEN_DOORFRAME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodWallWithDoor.PrimalItemStructure_WoodWallWithDoor'"
    WOODEN_DOOR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodDoor.PrimalItemStructure_WoodDoor'"
    WOODEN_DOUBLE_DOORFRAME = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Doorframes_Double/Wood/PrimalItemStructure_DoubleDoorframe_Wood.PrimalItemStructure_DoubleDoorframe_Wood'"
    WOODEN_DOUBLE_DOOR = "Blueprint'/Game/PrimalEarth/StructuresPlus/Doors/Doors_Double/Wood/PrimalItemStructure_DoubleDoor_Wood.PrimalItemStructure_DoubleDoor_Wood'"
    WOODEN_FENCE_FOUNDATION = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodFenceFoundation.PrimalItemStructure_WoodFenceFoundation'"
    WOODEN_FENCE_SUPPORT = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/FenceSupports/Wood/PrimalItemStructure_FenceSupport_Wood.PrimalItemStructure_FenceSupport_Wood'"
    WOODEN_FOUNDATION = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodFloor.PrimalItemStructure_WoodFloor'"
    WOODEN_HATCHFRAME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodCeilingWithTrapdoor.PrimalItemStructure_WoodCeilingWithTrapdoor'"
    WOODEN_LADDER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodLadder.PrimalItemStructure_WoodLadder'"
    WOODEN_PILLAR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodPillar.PrimalItemStructure_WoodPillar'"
    WOODEN_RAFT = "Blueprint'/Game/PrimalEarth/Items/Raft/PrimalItemRaft.PrimalItemRaft'"
    WOODEN_RAILING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodRailing.PrimalItemStructure_WoodRailing'"
    WOODEN_RAMP = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodRamp.PrimalItemStructure_WoodRamp'"
    WOODEN_SIGN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodSign.PrimalItemStructure_WoodSign'"
    WOODEN_SPIKE_WALL = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodSpikeWall.PrimalItemStructure_WoodSpikeWall'"
    WOODEN_STAIRCASE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodStairs.PrimalItemStructure_WoodStairs'"
    WOODEN_STAIRS = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Ramps/Wood/PrimalItemStructure_Ramp_Wood.PrimalItemStructure_Ramp_Wood'"
    WOODEN_TABLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_Furniture_WoodTable.PrimalItemStructure_Furniture_WoodTable'"
    WOODEN_TRAPDOOR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodTrapdoor.PrimalItemStructure_WoodTrapdoor'"
    WOODEN_TREE_PLATFORM = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_TreePlatform_Wood.PrimalItemStructure_TreePlatform_Wood'"
    WOODEN_TRIANGLE_CEILING = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Ceilings/Triangle/Wood/PrimalItemStructure_TriCeiling_Wood.PrimalItemStructure_TriCeiling_Wood'"
    WOODEN_TRIANGLE_FOUNDATION = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Foundations/Triangle/Wood/PrimalItemStructure_TriFoundation_Wood.PrimalItemStructure_TriFoundation_Wood'"
    WOODEN_TRIANGLE_ROOF = "Blueprint'/Game/PrimalEarth/StructuresPlus/Structures/Roofs_Tri/Wood/PrimalItemStructure_TriRoof_Wood.PrimalItemStructure_TriRoof_Wood'"
    WOODEN_WALL_SIGN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodSign_Wall.PrimalItemStructure_WoodSign_Wall'"
    WOODEN_WALL = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodWall.PrimalItemStructure_WoodWall'"
    WOODEN_WINDOWFRAME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodWallWithWindow.PrimalItemStructure_WoodWallWithWindow'"
    WOODEN_WINDOW = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Wooden/PrimalItemStructure_WoodWindow.PrimalItemStructure_WoodWindow'"


class ServerManagement:
    SHOW_MY_ADMIN_MANAGER = "ShowMyAdminManager"
    OPEN = "cheat Open {}:{}"  # IP : Port -> Joins the specified server
    BAN_PLAYER = "cheat BanPlayer {}"
    UNBAN_PLAYER = "cheat UnbanPlayer {}"
    KICK_PLAYER = "cheat KickPlayer {}"
    BROADCAST = "cheat Broadcast {}"
    SERVER_CHAT = "cheat ServerChat {}"
    SERVER_CHAT_TO = "cheat ServerChatTo {} {}"
    SERVER_CHAT_TO_Player = "cheat ServerChatToPlayer {} {}"
    SHOW_MESSAGE_OF_THE_DAY = "cheat ShowMessageOfTheDay"
    SET_MESSAGE_OF_THE_DAY = "cheat SetMessageOfTheDay {}"
    SET_ADMIN_ICON = "cheat SetAdminIcon {}"
    SHOW_IN_GAME_MENU = "cheat ShowInGameMenu"
    SHOW_DEBUG = "ShowDebug {}"


class Map:
    SET_DAY = "cheat SetDay {}"
    SET_TIME_OF_DAY = "cheat SetTimeOfDay {} {}"
    GET_ALL_STATE = "cheat GetAllState {}"
    DESTROY_FOLIAGE = "cheat DestroyFoliage {}"
    OPEN_MAP = "cheat OpenMap {}"
    SUMMON = "cheat Summon {}"
    COPY_COORDS_TO_CLIPBOARD = "ccc"
    CE = "cheat {}"
    DCM_SET = "DCMSET {} {}"
    FIND_MUTAGEN_DROPS = "cheat FindMutagenDrops"
    START_NEAREST_HORDE = "cheat StartNearestHorde {} {}"
    LIST_ACTIVE_HORDE_EVENTS = "cheat ListActiveHordeEvents"


class Spectator:
    ENABLE_SPECTATOR = "cheat EnableSpectator"
    STOP_SPECTATING = "cheat StopSpectating"
    REQUEST_SPECTATOR = "cheat RequestSpectator {}"


class CreativeMode:
    ENABLE_CHEATS = "EnableCheats {}"
    GIVE_CREATIVE_MODE = "cheat GCM"
    GIVE_CREATIVE_MODE_TO_TARGET = "cheat GiveCreativeModeToTarget"
    GIVE_CREATIVE_MODE_TO_PLAYER = "cheat GiveCreativeModeToPlayer {}"


class Teleportation:
    TELEPORT = "cheat Teleport"
    TELEPORT_PLAYER_ID_TO_ME = "cheat TeleportPlayerIdToMe {}"
    TELEPORT_PLAYER_NAME_TO_ME = "cheat TeleportPlayerNameToMe {}"
    TELEPORT_TO_PLAYER = "cheat TeleportToPlayer {}"
    TELEPORT_TO_PLAYER_NAME = "cheat TeleportToPlayerName {}"
    TELEPORT_TO_ACTOR_LOCATION = "cheat TeleportToActorLocation {}"
    TP = "cheat TP {}"
    TP_COORDS = "cheat TPCoords {} {} {}"
    SPI = "cheat SPI {} {} {} {} {}"
    SET_PLAYER_POS = "cheat SetPlayerPos {} {} {}"
    MOVE_TARGET_TO = "cheat MoveTargetTo {} {} {}"
    TELEPORT_TO_ACTIVE_HORDE = "cheat TeleportToActiveHorde {}"


class TribeManagement:
    TRIBE_MESSAGE = "cheat TribeMessage {} {}"
    RENAME_TRIBE = "cheat RenameTribe {} {}"
    GET_TRIBE_ID_PLAYER_LIST = "cheat GetTribeIdPlayerList {}"
    FORCE_PLAYER_TO_JOIN_TARGET_TRIBE = "cheat ForcePlayerToJoinTargetTribe {}"
    FORCE_JOIN_TRIBE = "cheat ForceJoinTribe"
    FORCE_TRIBE_ADMIN = "cheat MakeTribeAdmin"
    FORCE_TRIBE_FOUNDER = "cheat MakeTribeFounder"
    DESTROY_TRIBE_DINOS = "cheat DestroyTribeDinos"
    DESTROY_TRIBE_PLAYERS = "cheat DestroyTribePlayers"
    DESTROY_TRIBE_STRUCTURES = "cheat DestroyTribeStructures"
    DESTROY_TRIBE_ID = "cheat DestroyTribeId {}"
    DESTROY_TRIBE_ID_DINOS = "cheat DestroyTribeIdDinos {}"
    DESTROY_TRIBE_ID_PLAYERS = "cheat DestroyTribeIdPlayers {}"
    DESTROY_TRIBE_ID_STRUCTURES = "cheat DestroyTribeIdStructures {}"
    DESTROY_TRIBE_STRUCTURES_LESS_THAN = "cheat DestroyTribeStructuresLessThan {} {}"


class DinoManagement:
    TAKE_ALL_DINO = "cheat TakeAllDino"
    LEVEL_UP = "cheat LevelUp {} {}"
    GIVE_EXP_TO_TARGET = "cheat GiveExpToTarget {} {} {}"
    KILL_AOE = "cheat KillAOE {} {}"
    LEVEL_UPAOE = "cheat LevelUpAOE {} {} {}"
    LEVEL_UP_TARGET = "cheat LevelUpTarget {} {}"
    DESTROY_ALL = "cheat DestroyAll {}"
    DESTROY_WILD_DINO_CLASSES = "cheat DestroyWildDinoClasses {}"
    DESTROY_ALL_ENEMIES = "cheat DestroyAllEnemies"
    DESTROY_MY_TARGET = "cheat DestroyMyTarget"
    DESTROY_TRIBE_DINOS = "cheat DestroyTribeDinos"
    DESTROY_TRIBE_ID_DINOS = "cheat DestroyTribeIdDinos {}"
    DESTROY_WILD_DINOS = "cheat DestroyWildDinos"
    ADD_EXPERIENCE = "cheat AddExperience {} {} {}"
    DO_TAME = "cheat DoTame"
    DUMP_DINO_STATS = "cheat DumpDinoStats"
    FORCE_TAME = "cheat ForceTame"
    FORCE_TAME_AOE = "cheat ForceTameAOE {}"
    RAIN_CRITTERS = "cheat RainCritters {} {} {}"
    RAIN_DINOS = "cheat RainDinos {} {} {}"
    RAIN_DANGER = "cheat RainDanger {} {} {}"
    SDF = "cheat SDF {} {} {}"
    SIMPLE_DINO_SPAWN = "cheat SDF {} {} {}"
    SET_BABY_AGE = "cheat SetBabyAge {}"
    SET_IMPRINT_QUALITY = "cheat SetImprintQuality {}"
    SET_IMPRINTED_PLAYER = "cheat SetImprintedPlayer {} {}"
    SET_STATS_ON_TARGET = "cheat SetStatOnTarget {} {}"
    TRANSFER_IMPRINTS = "cheat TransferImprints {} {} {}"
    SET_TARGET_DINO_COLOR = "cheat SetTargetDinoColor {} {}"
    SPAWN_ACTOR = 'cheat SpawnActor "{}" {} {} {}'
    SPAWN_ACTOR_SPREAD = 'cheat SpawnActorSpread "{}" {} {} {} {} {}'
    SPAWN_DINO = 'cheat SpawnDino "{}" {} {} {} {}'
    SUMMON = "cheat Summon {}"
    SUMMON_TAMED = "cheat SummonTamed {}"
    GM_SUMMON = 'cheat GMSummon "{}" {}'
    GIVE_DINO_SET = "cheat GiveDinoSet {} {}"
    SPAWN_EXACT_DINO = 'cheat SpawnExactDino "{}" "{}" {} {} {} "{}" "{}" "{}" {} {} "{}" "{}" "{}" {} {} "{}" {} {} {} {} {}'
    SPAWN_SETUP_DINO = 'cheat SpawnSetupDino "{}" "{}" {} {} "{}" {} {} {}'
    FORCE_POOP = "cheat ForcePoop"
    CLEAR_CRYO_SICKNESS = "cheat ClearCryoSickness"


class ItemManagement:
    DEBUG_STRUCTURES = "DebugStructures"
    TAKE_ALL_STRUCTURE = "cheat TakeAllStructure"
    DESTROY_ALL = "cheat DestroyAll {}"
    DESTROY_MY_TARGET = "cheat DestroyMyTarget"
    DESTROY_STRUCTURES = "cheat DestroyStructures"
    DESTROY_TRIBE_STRUCTURES = "cheat DestroyTribeStructures"
    DESTROY_TRIBE_ID_STRUCTURES = "cheat DestroyTribeIdStructures {}"
    DESTROY_TRIBE_STRUCTURES_LESS_THAN = "cheat DestroyTribeStructuresLessThan {} {}"
    FORCE_PLAYER_TO_JOIN_TARGET_TRIBE = "cheat ForcePlayerToJoinTargetTribe {}"
    FORCE_PLAYER_TO_JOIN_TRIBE = "cheat ForcePlayerToJoinTribe {} {}"
    FORCE_JOIN_TRIBE = "cheat ForceJoinTribe"
    FORCE_TRIBES = "cheat ForceTribes {} {} {}"
    GIVE_ALL_STRUCTURE = "cheat GiveAllStructure"
    MAKE_TRIBE_ADMIN = "cheat MakeTribeAdmin"
    MAKE_TRIBE_FOUNDER = "cheat MakeTribeFounder"
    REMOVE_TRIBE_ADMIN = "cheat RemoveTribeAdmin"
    TAKE_TRIBE = "cheat TakeTribe {}"
    GIVE_COLORS = "cheat GiveColors {}"
    GIVE_ITEM = 'cheat GiveItem "{}" {} {} {}'
    GIVE_ITEM_NUM = "cheat GiveItemNum {} {} {} {}"
    GIVE_ITEM_TO_PLAYER = 'cheat GiveItemToPlayer {} "{}" {} {} {}'
    GIVE_ITEM_NUM_TO_PLAYER = "cheat GiveItemNumToPlayer {} {} {} {} {}"
    GIVE_ENGRAMS = "cheat GiveEngrams"
    GIVE_ENGRAMS_TEK_ONLY = "cheat GiveEngramsTekOnly"
    GIVE_TEK_ENGRAMS_TO = "cheat GiveTekEngramsTo {} {}"
    GIVE_RESOURCES = "cheat GiveResources"
    GIVE_SLOT_ITEM = 'cheat GiveSlotItem "{}" {} {}'
    GIVE_SLOT_ITEM_NUM = "cheat GiveSlotItemNum {} {} {}"
    GIVE_TO_ME = "cheat GiveToMe"
    GIVE_ARMOUR_SET = "cheat GiveArmourSet {} {}"
    GIVE_WEAPON_SET = "cheat GiveWeaponSet {} {}"
    GIVE_ITEM_SET = "cheat GiveItemSet {}"


class PlayerManagement:
    UNBAN_PLAYER = "cheat UnbanPlayer {}"
    KICK_PLAYER = "cheat KickPlayer {}"
    BAN_PLAYER = "cheat BanPlayer {}"
    KILL = "cheat Kill"
    KILL_PLAYER = "cheat KillPlayer {}"
    KILL_AOE = "cheat KillAOE {} {}"
    SET_CHEAT_PLAYER = "cheat SetCheatPlayer {}"
    CLEAR_PLAYER_INVENTORY = "cheat ClearPlayerInventory {} {} {} {}"
    GIVE_EXP_TO_TARGET = "cheat GiveExpToTarget {} {} {}"
    RENAME_PLAYER = "cheat RenamePlayer {} {}"
    LEVEL_UP = "cheat LevelUp {} {}"
    LEVEL_UPAOE = "cheat LevelUpAOE {} {} {}"
    LEVEL_UP_TARGET = "cheat LevelUpTarget {} {}"
    DESTROY_ALL = "cheat DestroyAll {}"
    DESTROY_TRIBE_PLAYERS = "cheat DestroyTribePlayers"
    DESTROY_TRIBE_ID_PLAYERS = "cheat DestroyTribeIdPlayers"
    ADD_EXPERIENCE = "cheat AddExperience {} {} {}"
    UNLOCK_ENGRAM = 'cheat UnlockEngram "{}"'
    HIDE_RIDERS = "cheat HideRiders {}"
    CHANGE_SIZE = "cheat ChangeSize {}"
    CLEAR_TUTORIALS = "cheat ClearTutorials"
    ENEMY_INVISIBLE = "cheat EnemyInvisible {}"
    EXEC_SET_SLEEPING = "cheat ExecSetSleeping {}"
    FLY = "cheat Fly"
    GHOST = "cheat Ghost"
    GIVE_EXP_TO_PLAYER = "cheat GiveExpToPlayer {} {} {} {}"
    GM_BUFF = "cheat GMBuff"
    ENV_QA = "cheat EnvQA"
    GOD = "cheat God"
    HIDE_TUTORIAL = "cheat HideTutorial {}"
    HURT_ME = "cheat HurtMe {}"
    INFINITE_STATS = "cheat InfiniteStats"
    LEAVE_ME_ALONE = "cheat LeaveMeAlone"
    ON_TOGGLE_IN_GAME_MENU = "cheat OnToggleInGameMenu"
    PLAYER_COMMAND = "cheat PlayerCommand {}"
    SET_FACIAL_HAIR_PERCENT = "cheat SetFacialHairPercent {}"
    SET_FACIAL_HAIR_STYLE = "cheat SetFacialHairStyle {}"
    SET_HEAD_HAIR_PERCENT = "cheat SetHeadHairPercent {}"
    SET_HEAD_HAIR_STYLE = "cheat SetHeadHairStyle {}"
    SET_GOD_MODE = "cheat SetGodMode {}"
    SET_TARGET_PLAYER_BODY_VAL = "cheat SetTargetPlayerBodyVal {} {}"
    SET_TARGET_PLAYER_COLOR_VAL = "cheat SetTargetPlayerColorVal {} {}"
    SHOW_TUTORIAL = "cheat ShowTutorial {} {}"
    SUICIDE = "cheat Suicide"
    TOGGLE_INFINITE_AMMO = "cheat ToggleInfiniteAmmo"
    WALK = "cheat Walk"
    TOGGLE_GUN = "cheat ToggleGun"
    REFILL_STATS = "cheat RefillStats"
    CLEAR_MY_BUFFS = "cheat ClearMyBuffs"
    SET_MY_TARGET_SLEEPING = "cheat SetMyTargetSleeping {}"
    MAX_ASCEND = "cheat MaxAscend {}"
    DEFEAT_BOSS = "cheat DefeatBoss {} {} {}"
    DEFEAT_ALL_BOSSES = "cheat DefeatAllBosses {}"
    GIVE_ALL_EXPLORER_NOTES = "cheat GiveAllExplorerNotes"
    GIVE_EXPLORER_NOTE = "cheat GiveExplorerNote {}"
    ADD_HEXAGONS = "cheat AddHexagons {}"
    INFINITE_WEIGHT = "cheat InfiniteWeight"
    GIVE_ITEM_TO_PLAYER = 'cheat GiveItemToPlayer {} "{}" {} {} {}'
    GIVE_ITEM_NUM_TO_PLAYER = "cheat GiveItemNumToPlayer {} {} {} {} {}"
    GIVE_TEK_ENGRAMS_TO = "cheat GiveTekEngramsTo {} {}"





class Chibis:
    CHIBI_PARTY_REX = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_PartyRex.PrimalItemSkin_ChibiDino_PartyRex'"
    CHIBI_ALLOSAURUS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Allosaurus.PrimalItemSkin_ChibiDino_Allosaurus'"
    CHIBI_AMMONITE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Ammonite.PrimalItemSkin_ChibiDino_Ammonite'"
    CHIBI_ANKYLOSAURUS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Ankylosaurus.PrimalItemSkin_ChibiDino_Ankylosaurus'"
    CHIBI_ARGENTAVIS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Argent.PrimalItemSkin_ChibiDino_Argent'"
    CHIBI_ASTROCETUS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Astrocetus.PrimalItemSkin_ChibiDino_Astrocetus'"
    CHIBI_BARYONYX = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Baryonyx.PrimalItemSkin_ChibiDino_Baryonyx'"
    CHIBI_BASILISK = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Basilisk.PrimalItemSkin_ChibiDino_Basilisk'"
    CHIBI_BEELZEBUFO = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Beelzebufo.PrimalItemSkin_ChibiDino_Beelzebufo'"
    CHIBI_BLOODSTALKER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_BogSpider.PrimalItemSkin_ChibiDino_BogSpider'"
    CHIBI_BONNET_OTTER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_OtterBonnet.PrimalItemSkin_ChibiDino_OtterBonnet'"
    CHIBI_BRONTOSAURUS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Bronto.PrimalItemSkin_ChibiDino_Bronto'"
    CHIBI_BROODMOTHER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_BroodMother.PrimalItemSkin_ChibiDino_BroodMother'"
    CHIBI_BULBDOG = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Bulbdog.PrimalItemSkin_ChibiDino_Bulbdog'"
    CHIBI_BUNNY = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Bunny.PrimalItemSkin_ChibiDino_Bunny'"
    CHIBI_CARBONEMYS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Carbonemys.PrimalItemSkin_ChibiDino_Carbonemys'"
    CHIBI_CARNO = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Carnotaurus.PrimalItemSkin_ChibiDino_Carnotaurus'"
    CHIBI_CASTROIDES = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Castroides.PrimalItemSkin_ChibiDino_Castroides'"
    CHIBI_CNIDARIA = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Cnidaria.PrimalItemSkin_ChibiDino_Cnidaria'"
    CHIBI_CRYSTAL_WYVERN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_WyvernCrystal.PrimalItemSkin_ChibiDino_WyvernCrystal'"
    CHIBI_DAEODON = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Daeodon.PrimalItemSkin_ChibiDino_Daeodon'"
    CHIBI_DIREBEAR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Direbear.PrimalItemSkin_ChibiDino_Direbear'"
    CHIBI_DIREWOLF = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Direwolf.PrimalItemSkin_ChibiDino_Direwolf'"
    CHIBI_DODO = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Dodo.PrimalItemSkin_ChibiDino_Dodo'"
    CHIBI_DOEDICURUS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Doedicurus.PrimalItemSkin_ChibiDino_Doedicurus'"
    CHIBI_DUNKLEOSTEUS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Dunkleo.PrimalItemSkin_ChibiDino_Dunkleo'"
    CHIBI_ENFORCER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Enforcer.PrimalItemSkin_ChibiDino_Enforcer'"
    CHIBI_EQUUS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Equus.PrimalItemSkin_ChibiDino_Equus'"
    CHIBI_FEATHERLIGHT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Featherlight.PrimalItemSkin_ChibiDino_Featherlight'"
    CHIBI_FEROX_LARGE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Shapeshifter_Large.PrimalItemSkin_ChibiDino_Shapeshifter_Large'"
    CHIBI_FEROX_SMALL = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Shapeshifter_Small.PrimalItemSkin_ChibiDino_Shapeshifter_Small'"
    CHIBI_GACHA_CLAUS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_GachaClaus.PrimalItemSkin_ChibiDino_GachaClaus'"
    CHIBI_GASBAG = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Gasbag.PrimalItemSkin_ChibiDino_Gasbag'"
    CHIBI_GIGANOTOSAURUS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Gigant.PrimalItemSkin_ChibiDino_Gigant'"
    CHIBI_GIGANTOPITHECUS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Gigantopithecus.PrimalItemSkin_ChibiDino_Gigantopithecus'"
    CHIBI_GLOWTAIL = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Glowtail.PrimalItemSkin_ChibiDino_Glowtail'"
    CHIBI_GRIFFIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Griffin.PrimalItemSkin_ChibiDino_Griffin'"
    CHIBI_IGUANODON = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Iguanodon.PrimalItemSkin_ChibiDino_Iguanodon'"
    CHIBI_KARKINOS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Karkinos.PrimalItemSkin_ChibiDino_Karkinos'"
    CHIBI_KENTROSAURUS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Kentrosaurus.PrimalItemSkin_ChibiDino_Kentrosaurus'"
    CHIBI_MAGMASAUR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Cherufe.PrimalItemSkin_ChibiDino_Cherufe'"
    CHIBI_MAMMOTH = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Mammoth.PrimalItemSkin_ChibiDino_Mammoth'"
    CHIBI_MANAGARMR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Managarmr.PrimalItemSkin_ChibiDino_Managarmr'"
    CHIBI_MANTA = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Manta.PrimalItemSkin_ChibiDino_Manta'"
    CHIBI_MANTIS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Mantis.PrimalItemSkin_ChibiDino_Mantis'"
    CHIBI_MEGALANIA = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Megalania.PrimalItemSkin_ChibiDino_Megalania'"
    CHIBI_MEGALOCEROS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Megaloceros.PrimalItemSkin_ChibiDino_Megaloceros'"
    CHIBI_MEGALODON = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Megalodon.PrimalItemSkin_ChibiDino_Megalodon'"
    CHIBI_MEGATHERIUM = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Megatherium.PrimalItemSkin_ChibiDino_Megatherium'"
    CHIBI_MESOPITHECUS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Mesopithecus.PrimalItemSkin_ChibiDino_Mesopithecus'"
    CHIBI_MOSCHOPS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Moschops.PrimalItemSkin_ChibiDino_Moschops'"
    CHIBI_OTTER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Otter.PrimalItemSkin_ChibiDino_Otter'"
    CHIBI_OVIRAPTOR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Oviraptor.PrimalItemSkin_ChibiDino_Oviraptor'"
    CHIBI_OVIS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Sheep.PrimalItemSkin_ChibiDino_Sheep'"
    CHIBI_PARACERATHERIUM = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Paraceratherium.PrimalItemSkin_ChibiDino_Paraceratherium'"
    CHIBI_PARASAUR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Parasaur.PrimalItemSkin_ChibiDino_Parasaur'"
    CHIBI_PHIOMIA = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Phiomia.PrimalItemSkin_ChibiDino_Phiomia'"
    CHIBI_PHOENIX = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Phoenix.PrimalItemSkin_ChibiDino_Phoenix'"
    CHIBI_PLESIOSAUR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Plesiosaur.PrimalItemSkin_ChibiDino_Plesiosaur'"
    CHIBI_PROCOPTODON = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Procoptodon.PrimalItemSkin_ChibiDino_Procoptodon'"
    CHIBI_PTERANODON = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Pteranodon.PrimalItemSkin_ChibiDino_Pteranodon'"
    CHIBI_PULMONOSCORPIUS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Pulmonoscorpius.PrimalItemSkin_ChibiDino_Pulmonoscorpius'"
    CHIBI_QUETZAL = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Quetzal.PrimalItemSkin_ChibiDino_Quetzal'"
    CHIBI_RAPTOR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Raptor.PrimalItemSkin_ChibiDino_Raptor'"
    CHIBI_REAPER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Reaper.PrimalItemSkin_ChibiDino_Reaper'"
    CHIBI_REINDEER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Reindeer.PrimalItemSkin_ChibiDino_Reindeer'"
    CHIBI_REX = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Rex.PrimalItemSkin_ChibiDino_Rex'"
    CHIBI_RHINO = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_WoollyRhino.PrimalItemSkin_ChibiDino_WoollyRhino'"
    CHIBI_ROCK_DRAKE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_RockDrake.PrimalItemSkin_ChibiDino_RockDrake'"
    CHIBI_ROCK_GOLEM = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_RockGolem.PrimalItemSkin_ChibiDino_RockGolem'"
    CHIBI_ROLLRAT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_MoleRat.PrimalItemSkin_ChibiDino_MoleRat'"
    CHIBI_SABERTOOTH = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Saber.PrimalItemSkin_ChibiDino_Saber'"
    CHIBI_SARCO = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Sarco.PrimalItemSkin_ChibiDino_Sarco'"
    CHIBI_SEEKER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Seeker.PrimalItemSkin_ChibiDino_Seeker'"
    CHIBI_SHADOWMANE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_ShadowMane.PrimalItemSkin_ChibiDino_ShadowMane'"
    CHIBI_SHINEHORN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Shinehorn.PrimalItemSkin_ChibiDino_Shinehorn'"
    CHIBI_SKELETAL_BRONTOSAURUS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Bronto_Bone.PrimalItemSkin_ChibiDino_Bronto_Bone'"
    CHIBI_SKELETAL_CARNO = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Carnotaurus_Bone.PrimalItemSkin_ChibiDino_Carnotaurus_Bone'"
    CHIBI_SKELETAL_GIGANOTOSAURUS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Gigant_Bone.PrimalItemSkin_ChibiDino_Gigant_Bone'"
    CHIBI_SKELETAL_JERBOA = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Jerboa_Bone.PrimalItemSkin_ChibiDino_Jerboa_Bone'"
    CHIBI_SKELETAL_QUETZAL = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Quetzal_Bone.PrimalItemSkin_ChibiDino_Quetzal_Bone'"
    CHIBI_SKELETAL_RAPTOR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Raptor_Bone.PrimalItemSkin_ChibiDino_Raptor_Bone'"
    CHIBI_SKELETAL_REX = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Rex_Bone.PrimalItemSkin_ChibiDino_Rex_Bone'"
    CHIBI_SKELETAL_STEGO = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Stego_Bone.PrimalItemSkin_ChibiDino_Stego_Bone'"
    CHIBI_SKELETAL_TRIKE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Trike_Bone.PrimalItemSkin_ChibiDino_Trike_Bone'"
    CHIBI_SKELETAL_WYVERN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Wyvern_Bone.PrimalItemSkin_ChibiDino_Wyvern_Bone'"
    CHIBI_SNOW_OWL = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_SnowOwl.PrimalItemSkin_ChibiDino_SnowOwl'"
    CHIBI_SPINO = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Spino.PrimalItemSkin_ChibiDino_Spino'"
    CHIBI_STEGO = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Stego.PrimalItemSkin_ChibiDino_Stego'"
    CHIBI_TAPEJARA = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Tapejara.PrimalItemSkin_ChibiDino_Tapejara'"
    CHIBI_TERROR_BIRD = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_TerrorBird.PrimalItemSkin_ChibiDino_TerrorBird'"
    CHIBI_THERIZINO = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Therizino.PrimalItemSkin_ChibiDino_Therizino'"
    CHIBI_THYLACOLEO = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Thylacoleo.PrimalItemSkin_ChibiDino_Thylacoleo'"
    CHIBI_TRIKE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Trike.PrimalItemSkin_ChibiDino_Trike'"
    CHIBI_TROODON = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Troodon.PrimalItemSkin_ChibiDino_Troodon'"
    CHIBI_TROPEOGNATHUS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Tropeognathus.PrimalItemSkin_ChibiDino_Tropeognathus'"
    CHIBI_TUSOTEUTHIS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Tuso.PrimalItemSkin_ChibiDino_Tuso'"
    CHIBI_UNICORN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Unicorn.PrimalItemSkin_ChibiDino_Unicorn'"
    CHIBI_VELONASAUR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Velonasaur.PrimalItemSkin_ChibiDino_Velonasaur'"
    CHIBI_WYVERN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Wyvern.PrimalItemSkin_ChibiDino_Wyvern'"
    CHIBI_YUTYRANNUS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Yutyrannus.PrimalItemSkin_ChibiDino_Yutyrannus'"
    CHIBI_ZOMBIE_WYVERN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Wyvern_Zombie.PrimalItemSkin_ChibiDino_Wyvern_Zombie'"
    PAIR_O_SAURS_CHIBI = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Pairosaurs_VDay.PrimalItemSkin_ChibiDino_Pairosaurs_VDay'"
    TEENY_TINY_TITANO = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_Titano.PrimalItemSkin_ChibiDino_Titano'"
    WHITE_COLLAR_KAIRUKU = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/ChibiDinos/PrimalItemSkin_ChibiDino_TophatKairuku.PrimalItemSkin_ChibiDino_TophatKairuku'"


class Weapons:
    ADMIN_BLINK_RIFLE = "Blueprint'/Game/Extinction/Weapon_AdminBlinkRifle/PrimalItem_WeaponAdminBlinkRifle.PrimalItem_WeaponAdminBlinkRifle'"
    ASSAULT_RIFLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponRifle.PrimalItem_WeaponRifle'"
    BEAR_TRAP = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_BearTrap.PrimalItemStructure_BearTrap'"
    BOLA = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponBola.PrimalItem_WeaponBola'"
    BOOMERANG = "Blueprint'/Game/ScorchedEarth/WeaponBoomerang/PrimalItem_WeaponBoomerang.PrimalItem_WeaponBoomerang'"
    BOW = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponBow.PrimalItem_WeaponBow'"
    C4_REMOTE_DETONATOR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponC4.PrimalItem_WeaponC4'"
    CHAIN_BOLA = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItemAmmo_ChainBola.PrimalItemAmmo_ChainBola'"
    CHARGE_LANTERN = "Blueprint'/Game/Aberration/WeaponRadioactiveLanternCharge/PrimalItem_WeaponRadioactiveLanternCharge.PrimalItem_WeaponRadioactiveLanternCharge'"
    CLIMBING_PICK = "Blueprint'/Game/Aberration/CoreBlueprints/Weapons/PrimalItem_WeaponClimbPick.PrimalItem_WeaponClimbPick'"
    CLUSTER_GRENADE = "Blueprint'/Game/ScorchedEarth/WeaponClusterGrenade/PrimalItem_WeaponClusterGrenade.PrimalItem_WeaponClusterGrenade'"
    COMPOUND_BOW = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponCompoundBow.PrimalItem_WeaponCompoundBow'"
    CROSSBOW = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponCrossbow.PrimalItem_WeaponCrossbow'"
    CRUISE_MISSILE = "Blueprint'/Game/Genesis/Weapons/CruiseMissile/PrimalItem_WeaponTekCruiseMissile.PrimalItem_WeaponTekCruiseMissile'"
    ELECTRIC_PROD = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponProd.PrimalItem_WeaponProd'"
    FABRICATED_PISTOL = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponMachinedPistol.PrimalItem_WeaponMachinedPistol'"
    FABRICATED_SNIPER_RIFLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponMachinedSniper.PrimalItem_WeaponMachinedSniper'"
    FLAMETHROWER = "Blueprint'/Game/ScorchedEarth/WeaponFlamethrower/PrimalItem_WeapFlamethrower.PrimalItem_WeapFlamethrower'"
    FLAMING_SPEAR = "Blueprint'/Game/Genesis/CoreBlueprints/Weapons/Mission/PrimalItem_WeaponSpear_Flame_Gauntlet.PrimalItem_WeaponSpear_Flame_Gauntlet'"
    FLARE_GUN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponFlareGun.PrimalItem_WeaponFlareGun'"
    GLOW_STICK = "Blueprint'/Game/Aberration/WeaponGlowStickThrow/PrimalItem_GlowStick.PrimalItem_GlowStick'"
    GRENADE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponGrenade.PrimalItem_WeaponGrenade'"
    HANDCUFFS = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponHandcuffs.PrimalItem_WeaponHandcuffs'"
    HARPOON_LAUNCHER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponHarpoon.PrimalItem_WeaponHarpoon'"
    IMPROVISED_EXPLOSIVE_DEVICE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponTripwireC4.PrimalItem_WeaponTripwireC4'"
    LANCE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponLance.PrimalItem_WeaponLance'"
    LARGE_BEAR_TRAP = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Structures/Misc/PrimalItemStructure_BearTrap_Large.PrimalItemStructure_BearTrap_Large'"
    LASSO = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponLasso.PrimalItem_WeaponLasso'"
    LONGNECK_RIFLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponOneShotRifle.PrimalItem_WeaponOneShotRifle'"
    MINIGUN = "Blueprint'/Game/Genesis2/Weapons/MiniGun/PrimalItem_WeaponMinigun.PrimalItem_WeaponMinigun'"
    OIL_JAR = "Blueprint'/Game/ScorchedEarth/WeaponOilJar/PrimalItem_WeaponOilJar.PrimalItem_WeaponOilJar'"
    PIKE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponPike.PrimalItem_WeaponPike'"
    PLANT_SPECIES_Y_TRAP = "Blueprint'/Game/ScorchedEarth/WeaponPlantSpeciesY/PrimalItemStructure_PlantSpeciesYTrap.PrimalItemStructure_PlantSpeciesYTrap'"
    PLANT_SPECIES_Z_FRUIT = "Blueprint'/Game/Aberration/WeaponPlantSpeciesZ/PrimalItem_PlantSpeciesZ_Grenade.PrimalItem_PlantSpeciesZ_Grenade'"
    POISON_GRENADE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_PoisonGrenade.PrimalItem_PoisonGrenade'"
    PUMP_ACTION_SHOTGUN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponMachinedShotgun.PrimalItem_WeaponMachinedShotgun'"
    ROCKET_LAUNCHER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponRocketLauncher.PrimalItem_WeaponRocketLauncher'"
    SCOUT_REMOTE = "Blueprint'/Game/Extinction/Dinos/Scout/PrimalItem_WeaponScoutRemote.PrimalItem_WeaponScoutRemote'"
    SHOTGUN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponShotgun.PrimalItem_WeaponShotgun'"
    SIMPLE_PISTOL = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponGun.PrimalItem_WeaponGun'"
    SLINGSHOT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponSlingshot.PrimalItem_WeaponSlingshot'"
    SMOKE_GRENADE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_GasGrenade.PrimalItem_GasGrenade'"
    SPEAR = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponSpear.PrimalItem_WeaponSpear'"
    SPRAY_PAINTER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponSprayPaint.PrimalItem_WeaponSprayPaint'"
    SWORD = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponSword.PrimalItem_WeaponSword'"
    TEK_CLAWS = "Blueprint'/Game/Genesis/Weapons/TekHandBlades/PrimalItem_WeaponTekClaws.PrimalItem_WeaponTekClaws'"
    TEK_GRAVITY_GRENADE = "Blueprint'/Game/Extinction/CoreBlueprints/Weapons/PrimalItem_WeaponTekGravityGrenade.PrimalItem_WeaponTekGravityGrenade'"
    TEK_GRENADE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_TekGrenade.PrimalItem_TekGrenade'"
    TEK_GRENADE_LAUNCHER = "Blueprint'/Game/Genesis/Weapons/TekGrenadeLauncher/PrimalItem_WeaponTekGrenadeLauncher.PrimalItem_WeaponTekGrenadeLauncher'"
    TEK_RAILGUN = "Blueprint'/Game/Aberration/WeaponTekSniper/PrimalItem_TekSniper.PrimalItem_TekSniper'"
    TEK_RIFLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_TekRifle.PrimalItem_TekRifle'"
    TEK_SWORD = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponTekSword.PrimalItem_WeaponTekSword'"
    TRANSPONDER_TRACKER = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponTransGPS.PrimalItem_WeaponTransGPS'"
    TRIPWIRE_ALARM_TRAP = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponAlarmTrap.PrimalItem_WeaponAlarmTrap'"
    TRIPWIRE_NARCOTIC_TRAP = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponPoisonTrap.PrimalItem_WeaponPoisonTrap'"
    WOODEN_CLUB = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItem_WeaponStoneClub.PrimalItem_WeaponStoneClub'"
    FLASHLIGHT_ATTACHMENT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/WeaponAttachments/PrimalItemWeaponAttachment_Flashlight.PrimalItemWeaponAttachment_Flashlight'"
    HOLO_SCOPE_ATTACHMENT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/WeaponAttachments/PrimalItemWeaponAttachment_HoloScope.PrimalItemWeaponAttachment_HoloScope'"
    LASER_ATTACHMENT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/WeaponAttachments/PrimalItemWeaponAttachment_Laser.PrimalItemWeaponAttachment_Laser'"
    SCOPE_ATTACHMENT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/WeaponAttachments/PrimalItemWeaponAttachment_Scope.PrimalItemWeaponAttachment_Scope'"
    SILENCER_ATTACHMENT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/WeaponAttachments/PrimalItemWeaponAttachment_Silencer.PrimalItemWeaponAttachment_Silencer'"


import json

class Trie:
    @classmethod
    def setup(cls, words):
        root = Trie()
        for word in words:
            root.add_child(word)
        return root

    def __init__(self, value=None):
        self.value = value
        # use a hashmap to lookup child nodes in constant time
        # Example: {'a': Node('a'), 'o': Node(o)}
        self.children = {}

    def keys(self):
        return self.children.keys()

    def values(self):
        return self.children.values()

    def items(self):
        return self.children.items()

    def __contains__(self, item):
        return item in self.children

    def __getitem__(self, item):
        if item not in self:
            return None
        return self.children[item]

    def __setitem__(self, key, value):
        self.children[key] = value

    def add_child(self, word):
        if word == "":
            self["."] = None
            return None
        next_char, rest_of_string = word[:1], word[1:]
        # If the node already exists in the trie you are building,
        # query it and pass it to the next recursive call
        if next_char in self:
            self[next_char].add_child(rest_of_string)
            return

        # If the node does not exist, create a new one
        # and add it to its parent
        self[next_char] = Trie(next_char)
        # Move on to the next
        self[next_char].add_child(rest_of_string)

    def is_member(self, word):
        if word == "":
            return "." in self.children
        next_char, rest_of_string = word[:1], word[1:]
        if next_char == ".":
            for child in self.values():
                if child.is_member(rest_of_string):
                    return True
        else:
            if next_char in self:
                return self[next_char].is_member(rest_of_string)
        return False

    def is_like(self, word):
        if word == "":
            return True
        next_char, rest_of_string = word[:1], word[1:]
        if next_char == ".":
            for child in self.values():
                if child.is_like(rest_of_string):
                    return True
        else:
            if next_char in self:
                return self[next_char].is_like(rest_of_string)
        return False

    def get_like(self, word):
        if self.is_like(word):
            return self.get_like_helper(word, [], "", self)
        return []

    def get_like_helper(self, word, found: list, traced: str, root):
        next_char, rest_of_string = word[:1], word[1:]
        if word == "":
            if root.is_member(traced):
                found.append(traced)
            for child_char, child in self.items():
                if child_char != ".":
                    child.get_like_helper(word, found, f"{traced}{child_char}", root)
        elif self.is_member(traced) and traced != "":
            found.append(traced)
            return found
        elif next_char in self:
            self[next_char].get_like_helper(rest_of_string, found, f"{traced}{next_char}", root)
        return found

    def __str__(self):
        return json.dumps(children_dict(self), sort_keys=True, indent=2)

    def __repr__(self):
        items = []
        for k, v in self.__dict__.items():
            if k and k[0] != "_":
                items.append(f"\033[34m{k}\033[90m=\033[0m{repr(v)}\033[0m")
        args = ', '.join(items)
        return f'<\033[96m{type(self).__name__}\033[0m({args})>\033[0m'


def children_dict(child, content={}):
    if child is None:
        return None
    return {**content, **{k: children_dict(v) for k, v in child.items()}}


if __name__ == "__main__":
    words = ['one', 'two', 'three', 'only', 'onyx', 'ones']
    root = Trie.setup(words)

    word = 'on'
    print(root)
    print(f"is_member({'one'}, root) => ", root.is_member('one'))
    print(f"is_member({'onl'}, root) => ", root.is_member('onl'))
    print(f"is_like('{word}', root) => ", root.is_like(word))
    print(f"is_like(''), root) =>", root.is_like(''))
    print(f"get_like('{word}', root) => ", root.get_like(word))
